GeocodedWaypoint class

Annotations
  • @JsonSerializable.new()

Constructors

GeocodedWaypoint({String? geocoderStatus, String? placeId, List<String>? types, bool? partialMatch = false})
GeocodedWaypoint.fromJson(Map<String, dynamic> json)
factory

Properties

geocoderStatus → String?
JSON geocoder_status
final
hashCode → int
The hash code for this object.
no setterinherited
partialMatch → bool?
JSON partial_match
final
placeId → String?
JSON place_id
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited