Leg class

Annotations
  • @JsonSerializable.new()

Constructors

Leg({List<Step>? steps, String? startAddress, String? endAddress, Value? durationInTraffic, Time? arrivalTime, Time? departureTime, Location? startLocation, Location? endLocation, Value? duration, Value? distance})
Leg.fromJson(Map<String, dynamic> json)
factory

Properties

arrivalTime → Time?
JSON arrival_time
final
departureTime → Time?
JSON departure_time
final
distance → Value?
finalinherited
duration → Value?
finalinherited
durationInTraffic → Value?
JSON duration_in_traffic
final
endAddress → String?
JSON end_address
final
endLocation → Location?
JSON end_location
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAddress → String?
JSON start_address
final
startLocation → Location?
JSON start_location
finalinherited
steps → List<Step>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited