Line class

Annotations
  • @JsonSerializable.new()

Constructors

Line({required String name, required String shortName, required String color, required List<TransitAgency> agencies, required String url, required String icon, required String textColor, required VehicleType vehicle})
Line.fromJson(Map<String, dynamic> json)
factory

Properties

agencies → List<TransitAgency>
final
color → String
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String
JSON short_name
final
textColor → String
JSON text_color
final
url → String
final
vehicle → VehicleType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited