Route class

Annotations
  • @JsonSerializable.new()

Constructors

Route({String? summary, List<Leg>? legs, String? copyrights, Polyline? overviewPolyline, List? warnings, List<num>? waypointOrder, Bounds? bounds, Fare? fare})
Route.fromJson(Map<String, dynamic> json)
factory

Properties

bounds → Bounds?
final
copyrights → String?
final
fare → Fare?
final
hashCode → int
The hash code for this object.
no setterinherited
legs → List<Leg>?
final
overviewPolyline → Polyline?
JSON overview_polyline
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String?
final
warnings → List?
final
waypointOrder → List<num>?
JSON waypoint_order
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited