Step class

Annotations
  • @JsonSerializable.new()

Constructors

Step({required TravelMode travelMode, required String htmlInstructions, required Polyline polyline, required Location startLocation, required Location endLocation, required Value duration, required Value distance, TransitDetails? transitDetails, String? maneuver})
Step.fromJson(Map<String, dynamic> json)
factory

Properties

distance → Value?
finalinherited
duration → Value?
finalinherited
endLocation → Location?
JSON end_location
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
htmlInstructions → String
JSON html_instructions
final
maneuver → String?
final
polyline → Polyline
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLocation → Location?
JSON start_location
finalinherited
transitDetails → TransitDetails?
JSON transit_details
final
travelMode → TravelMode
JSON travel_mode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited