TransitDetails class

Annotations
  • @JsonSerializable.new()

Constructors

TransitDetails({required Stop arrivalStop, required Stop departureStop, required Time arrivalTime, required Time departureTime, required String headsign, required num headway, required num numStops})
TransitDetails.fromJson(Map<String, dynamic> json)
factory

Properties

arrivalStop → Stop
JSON arrival_stop
final
arrivalTime → Time
JSON arrival_time
final
departureStop → Stop
JSON departure_stop
final
departureTime → Time
JSON departure_time
final
hashCode → int
The hash code for this object.
no setterinherited
headsign → String
final
headway → num
final
numStops → num
JSON num_stops
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited