VehicleType class

Annotations
  • @JsonSerializable.new()

Constructors

VehicleType({required String name, required String type, required String icon, required String localIcon})
VehicleType.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → String
final
localIcon → String
JSON local_icon
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

isType(String type) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

bus → const String
cableCar → const String
commuterTrain → const String
ferry → const String
funicular → const String
gondolaLift → const String
heavyRail → const String
highSpeedTrain → const String
intercityBus → const String
metroRail → const String
monorail → const String
other → const String
rail → const String
shareTaxi → const String
subway → const String
tram → const String
trolleyBus → const String