Waypoint class

Annotations
  • @JsonSerializable.new()

Constructors

Waypoint({required String value})
Waypoint.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAddress(String address) → Waypoint
fromEncodedPolyline(String polyline) → Waypoint
fromLocation(Location location) → Waypoint
fromPlaceId(String placeId) → Waypoint
optimize() → Waypoint