Photo class

Annotations
  • @JsonSerializable.new()

Constructors

Photo({String? photoReference, num? height, num? width, List<String>? htmlAttributions})
Photo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → num?
final
htmlAttributions → List<String>?
JSON html_attributions
final
photoReference → String?
JSON photo_reference
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → num?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited