PlaceOpeningHours class

Annotations
  • @JsonSerializable.new()

Constructors

PlaceOpeningHours({bool? openNow, List<PlaceOpeningHoursPeriod>? periods, List<PlaceSpecialDay>? specialDays, String? type, List<String>? weekdayText})
const
PlaceOpeningHours.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
openNow → bool?
final
periods → List<PlaceOpeningHoursPeriod>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specialDays → List<PlaceSpecialDay>?
final
type → String?
final
weekdayText → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited