PlacesSearchResponse class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

PlacesSearchResponse({ResponseStatus? status, String? errorMessage, List<PlacesSearchResult>? results, List<String>? htmlAttributions, String? nextPageToken})
PlacesSearchResponse.fromJson(Map<String, dynamic> json)
factory

Properties

errorMessage → String?
JSON error_message
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNoResults → bool
no setterinherited
htmlAttributions → List<String>?
JSON html_attributions
final
isDenied → bool
no setterinherited
isInvalid → bool
no setterinherited
isNotFound → bool
no setterinherited
isOk → bool
no setterinherited
isOverQueryLimit → bool
no setterinherited
nextPageToken → String?
JSON next_page_token
final
results → List<PlacesSearchResult>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ResponseStatus
finalinherited
unknownError → bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited