PlacesSearchResult class

Annotations
  • @JsonSerializable.new()

Constructors

PlacesSearchResult({String? id, String? reference, String? name, String? placeId, String? formattedAddress, List<Photo>? photos, List<AlternativeId>? altIds, List<String>? types, bool? permanentlyClosed, String? icon, Geometry? geometry, PlaceOpeningHours? openingHours, String? scope, PriceLevel? priceLevel, num? rating, String? vicinity})
PlacesSearchResult.fromJson(Map<String, dynamic> json)
factory

Properties

altIds → List<AlternativeId>?
JSON alt_ids
final
formattedAddress → String?
JSON formatted_address
final
geometry → Geometry?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
id → String?
final
name → String?
final
openingHours → PlaceOpeningHours?
JSON opening_hours
final
permanentlyClosed → bool?
JSON permanently_closed
final
photos → List<Photo>?
final
placeId → String?
JSON place_id
final
priceLevel → PriceLevel?
JSON price_level
final
rating → num?
final
reference → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String?
final
types → List<String>?
final
vicinity → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited