Prediction class

Annotations
  • @JsonSerializable.new()

Constructors

Prediction({String? description, String? id, List<Term>? terms, int? distanceMeters, String? placeId, String? reference, List<String>? types, List<MatchedSubstring>? matchedSubstrings, StructuredFormatting? structuredFormatting})
Prediction.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
final
distanceMeters → int?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
matchedSubstrings → List<MatchedSubstring>?
JSON matched_substrings
final
placeId → String?
JSON place_id
final
reference → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredFormatting → StructuredFormatting?
final
terms → List<Term>?
final
types → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited