Review class

Annotations
  • @JsonSerializable.new()

Constructors

Review({required String authorName, required num rating, required String relativeTimeDescription, required num time, String? authorUrl, String? language, String? originalLanguage, String? profilePhotoUrl, String? text, bool? translated})
const
Review.fromJson(Map<String, dynamic> json)
factory

Properties

authorName → String
JSON author_name
final
authorUrl → String?
JSON author_url
final
hashCode → int
The hash code for this object.
no setterinherited
language → String?
final
originalLanguage → String?
final
profilePhotoUrl → String?
JSON profile_photo_url
final
rating → num
final
relativeTimeDescription → String
JSON relative_time_description
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
final
time → num
final
translated → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited