StructuredFormatting class

Annotations
  • @JsonSerializable.new()

Constructors

StructuredFormatting({String? mainText, List<MatchedSubstring>? mainTextMatchedSubstrings, String? secondaryText})
StructuredFormatting.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mainText → String?
final
mainTextMatchedSubstrings → List<MatchedSubstring>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryText → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited