Term class

Annotations
  • @JsonSerializable.new()

Constructors

Term({required num offset, required String value})
Term.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
offset → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override