places_new library

Classes

AccessibilityOptions
Information about the accessibility options a place offers.
AddressComponent
The structured components that form the formatted address, if this information is available.
AddressDescriptor
A relational description of a location. Includes a ranked set of nearby landmarks and precise containing areas and their relationship to the target location.
Area
Area information and the area's relationship with the target location.
AreaSummary
Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details.
Attribution
Information about data providers of this place.
AuthorAttribution
Information about the author of the UGC data. Used in Photo, and Review.
AutocompleteSearchFilter
Structure of the body of Autocomplete Search requests.
BaseFilter<T extends Object>
BaseSessionFilter<T extends Object>
Base filter for session based requests.
Circle
ConnectorAggregation
EV charging information grouped by type, maxChargeRateKw. Shows EV charge aggregation of connectors that have the same type and max charge rate in kw.
ContainingPlace
Info about the place in which this place is located.
ContentBlock
A block of content that can be served individually.
ContextualContent
Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details.
CustomParseErrorLogger
Date
Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:
ErrorInfo
EVChargeOptions
Information about the EV Charge Station hosted in Place. Terminology follows https://afdc.energy.gov/fuels/electricity_infrastructure.html One port could charge one car at a time. One port has one or more connectors. One station has one or more ports.
EvOptions
Searchable EV options of a place search request.
FormattableText
Text representing a Place or query prediction. The text may be used as is or formatted.
FuelOptions
The most recent information about fuel options in a gas station. This information is updated regularly.
FuelPrice
Fuel price information for a given type.
GenerativeSummary
Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details.
GoogleErrorResponse
It is a wrapper for error responses from network calls
GoogleHTTPResponse<BodyType>
It is a http.BaseResponse wrapper representing a response of a network call.
GoogleMapsInterceptors
Utility class providing common interceptors for Google Maps APIs
Links to trigger different Google Maps actions.
Jsonable<T extends Object>
Justification
Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details.
Landmark
Basic landmark information and the landmark's relationship with the target location.
LatLng
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Leg
A leg is a single portion of a journey from one location to another.
LocalizedText
Localized variant of a text in a particular language. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#localizedtext
LocationBias
The region to search. This location serves as a bias which means results around given location might be returned.
LocationMultiArea
LocationRestriction
The region to search. This location serves as a restriction which means results outside given location will not be returned.
LocationRestrictionCircle
A circle region to search.
Money
Represents an amount of money with its currency type.
NearbySearchFilter
Structure of the body of Nearby Search requests:
OpeningHours
Information about business hour of the place.
ParkingOptions
Information about parking options for the place. A parking lot could support more than one option at the same time.
PaymentOptions
Payment options the place accepts.
Period
A period the place remains in openNow status.
Photo
Information about a photo of a place.
Place
All the information representing a Place.
PlaceDetailsFilter
PlacePrediction
Prediction results for a Place Autocomplete prediction.
PlacesAPINew
API service for the Places API (New): https://developers.google.com/maps/documentation/places/web-service/op-overview
PlacesResponse
Response DTO for Search Nearby and Search Text.
PlacesServiceNew
PlacesSuggestions
Response DTO for Search Nearby and Search Autocomplete.
PlusCode
Plus code (http://plus.codes) is a location reference with two formats: global code defining a 14mx14m (1/8000th of a degree) or smaller rectangle, and compound code, replacing the prefix with a reference location.
Point
Status changing points.
PriceRange
The price range associated with a Place. endPrice could be unset, which indicates a range without upper bound (e.g. "More than $100").
QueryPrediction
Prediction results for a Query Autocomplete prediction.
Rectangle
A rectangle is a latitude-longitude viewport, represented as two diagonally opposite low and high points. The low point marks the southwest corner of the rectangle, and the high point represents the northeast corner of the rectangle. A viewport is considered a closed region, meaning it includes its boundary. The latitude bounds must range between -90 to 90 degrees inclusive, and the longitude bounds must range between -180 to 180 degrees inclusive:
ReferencePoint
References
Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details.
RestAPI
RestAPIService<DataType extends Jsonable<Object>>
Review
Information about a review of a place.
RouteModifiers
Encapsulates a set of optional conditions to satisfy when calculating the routes.
RoutingParameters
Information about the accessibility options a place offers.
RoutingSummary
The duration and distance from the routing origin to a place in the response, and a second leg from that place to the destination, if requested. Note: Adding routingSummaries in the field mask without also including either the routingParameters.origin parameter or the searchAlongRouteParameters.polyline.encodedPolyline parameter in the request causes an error.
SessionTokenHandler
This class is used for Google Places API (New) Autocomplete / Details requests
SpecialDay
Structured information for special days that fall within the period that the returned opening hours cover. Special days are days that could impact the business hours of a place, e.g. Christmas day.
StringRange
Identifies a substring within a given text.
StructuredFormat
Contains a breakdown of a Place or query prediction into main text and secondary text.
SubDestination
Place resource name and id of sub destinations that relate to the place. For example, different terminals are different destinations of an airport.
Suggestion
An Autocomplete suggestion result.
TextSearchFilter
Structure of the body of Text Search requests.
Viewport
A latitude-longitude viewport, represented as two diagonally opposite low and high points. A viewport is considered a closed region, i.e. it includes its boundary. The latitude bounds must range between -90 to 90 degrees inclusive, and the longitude bounds must range between -180 to 180 degrees inclusive.

Enums

BusinessStatus
Business status for the place. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#businessstatus
Containment
Defines the spatial relationship between the target location and the area. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#containment
EvConnectorType
The type of electric vehicle (EV) charging connectors Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#evconnectortype
FuelType
Types of fuel. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#fueltype
PlaceType
PriceLevel
Price level of a place. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#pricelevel
RankPreferenceType
The type of ranking to use in a search like nearby search. Documentation: https://developers.google.com/maps/documentation/places/web-service/nearby-search#rankpreference
RoutingPreference
A set of values that specify factors to take into consideration when calculating the route. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/RoutingParameters#routingpreference
SecondaryHoursType
A type used to identify the type of secondary hours. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#secondaryhourstype
SpatialRelationship
Defines the spatial relationship between the target location and the landmark. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#spatialrelationship
TravelMode
Travel mode options. These options map to what Routes API offers. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/RoutingParameters#travelmode

Extensions

$AccessibilityOptionsCopyWithExtension on AccessibilityOptions
This Extension on AccessibilityOptions is to generate the code for a copyWith(...) function.
$AddressComponentCopyWithExtension on AddressComponent
This Extension on AddressComponent is to generate the code for a copyWith(...) function.
$AddressDescriptorCopyWithExtension on AddressDescriptor
This Extension on AddressDescriptor is to generate the code for a copyWith(...) function.
$AreaCopyWithExtension on Area
This Extension on Area is to generate the code for a copyWith(...) function.
$AreaSummaryCopyWithExtension on AreaSummary
This Extension on AreaSummary is to generate the code for a copyWith(...) function.
$AttributionCopyWithExtension on Attribution
This Extension on Attribution is to generate the code for a copyWith(...) function.
$AuthorAttributionCopyWithExtension on AuthorAttribution
This Extension on AuthorAttribution is to generate the code for a copyWith(...) function.
$AutocompleteSearchFilterCopyWithExtension on AutocompleteSearchFilter
This Extension on AutocompleteSearchFilter is to generate the code for a copyWith(...) function.
$CircleCopyWithExtension on Circle
This Extension on Circle is to generate the code for a copyWith(...) function.
$ConnectorAggregationCopyWithExtension on ConnectorAggregation
This Extension on ConnectorAggregation is to generate the code for a copyWith(...) function.
$ContainingPlaceCopyWithExtension on ContainingPlace
This Extension on ContainingPlace is to generate the code for a copyWith(...) function.
$ContentBlockCopyWithExtension on ContentBlock
This Extension on ContentBlock is to generate the code for a copyWith(...) function.
$ContextualContentCopyWithExtension on ContextualContent
This Extension on ContextualContent is to generate the code for a copyWith(...) function.
$DateCopyWithExtension on Date
This Extension on Date is to generate the code for a copyWith(...) function.
$EVChargeOptionsCopyWithExtension on EVChargeOptions
This Extension on EVChargeOptions is to generate the code for a copyWith(...) function.
$EvOptionsCopyWithExtension on EvOptions
This Extension on EvOptions is to generate the code for a copyWith(...) function.
$FormattableTextCopyWithExtension on FormattableText
This Extension on FormattableText is to generate the code for a copyWith(...) function.
$FuelOptionsCopyWithExtension on FuelOptions
This Extension on FuelOptions is to generate the code for a copyWith(...) function.
$FuelPriceCopyWithExtension on FuelPrice
This Extension on FuelPrice is to generate the code for a copyWith(...) function.
$GenerativeSummaryCopyWithExtension on GenerativeSummary
This Extension on GenerativeSummary is to generate the code for a copyWith(...) function.
$GoogleErrorResponseCopyWithExtension on GoogleErrorResponse
This Extension on GoogleErrorResponse is to generate the code for a copyWith(...) function.
$GoogleMapsLinksCopyWithExtension on GoogleMapsLinks
This Extension on GoogleMapsLinks is to generate the code for a copyWith(...) function.
$JustificationCopyWithExtension on Justification
This Extension on Justification is to generate the code for a copyWith(...) function.
$LandmarkCopyWithExtension on Landmark
This Extension on Landmark is to generate the code for a copyWith(...) function.
$LatLngCopyWithExtension on LatLng
This Extension on LatLng is to generate the code for a copyWith(...) function.
$LegCopyWithExtension on Leg
This Extension on Leg is to generate the code for a copyWith(...) function.
$LocalizedTextCopyWithExtension on LocalizedText
This Extension on LocalizedText is to generate the code for a copyWith(...) function.
$LocationBiasCopyWithExtension on LocationBias
This Extension on LocationBias is to generate the code for a copyWith(...) function.
$LocationMultiAreaCopyWithExtension on LocationMultiArea
This Extension on LocationMultiArea is to generate the code for a copyWith(...) function.
$LocationRestrictionCircleCopyWithExtension on LocationRestrictionCircle
This Extension on LocationRestrictionCircle is to generate the code for a copyWith(...) function.
$LocationRestrictionCopyWithExtension on LocationRestriction
This Extension on LocationRestriction is to generate the code for a copyWith(...) function.
$MoneyCopyWithExtension on Money
This Extension on Money is to generate the code for a copyWith(...) function.
$NearbySearchFilterCopyWithExtension on NearbySearchFilter
This Extension on NearbySearchFilter is to generate the code for a copyWith(...) function.
$OpeningHoursCopyWithExtension on OpeningHours
This Extension on OpeningHours is to generate the code for a copyWith(...) function.
$ParkingOptionsCopyWithExtension on ParkingOptions
This Extension on ParkingOptions is to generate the code for a copyWith(...) function.
$PaymentOptionsCopyWithExtension on PaymentOptions
This Extension on PaymentOptions is to generate the code for a copyWith(...) function.
$PeriodCopyWithExtension on Period
This Extension on Period is to generate the code for a copyWith(...) function.
$PhotoCopyWithExtension on Photo
This Extension on Photo is to generate the code for a copyWith(...) function.
$PlaceCopyWithExtension on Place
This Extension on Place is to generate the code for a copyWith(...) function.
$PlaceDetailsFilterCopyWithExtension on PlaceDetailsFilter
This Extension on PlaceDetailsFilter is to generate the code for a copyWith(...) function.
$PlacePredictionCopyWithExtension on PlacePrediction
This Extension on PlacePrediction is to generate the code for a copyWith(...) function.
$PlacesResponseCopyWithExtension on PlacesResponse
This Extension on PlacesResponse is to generate the code for a copyWith(...) function.
$PlacesSuggestionsCopyWithExtension on PlacesSuggestions
This Extension on PlacesSuggestions is to generate the code for a copyWith(...) function.
$PlusCodeCopyWithExtension on PlusCode
This Extension on PlusCode is to generate the code for a copyWith(...) function.
$PointCopyWithExtension on Point
This Extension on Point is to generate the code for a copyWith(...) function.
$PriceRangeCopyWithExtension on PriceRange
This Extension on PriceRange is to generate the code for a copyWith(...) function.
$QueryPredictionCopyWithExtension on QueryPrediction
This Extension on QueryPrediction is to generate the code for a copyWith(...) function.
$RectangleCopyWithExtension on Rectangle
This Extension on Rectangle is to generate the code for a copyWith(...) function.
$ReferencePointCopyWithExtension on ReferencePoint
This Extension on ReferencePoint is to generate the code for a copyWith(...) function.
$ReferencesCopyWithExtension on References
This Extension on References is to generate the code for a copyWith(...) function.
$ReviewCopyWithExtension on Review
This Extension on Review is to generate the code for a copyWith(...) function.
$RouteModifiersCopyWithExtension on RouteModifiers
This Extension on RouteModifiers is to generate the code for a copyWith(...) function.
$RoutingParametersCopyWithExtension on RoutingParameters
This Extension on RoutingParameters is to generate the code for a copyWith(...) function.
$RoutingSummaryCopyWithExtension on RoutingSummary
This Extension on RoutingSummary is to generate the code for a copyWith(...) function.
$SpecialDayCopyWithExtension on SpecialDay
This Extension on SpecialDay is to generate the code for a copyWith(...) function.
$StringRangeCopyWithExtension on StringRange
This Extension on StringRange is to generate the code for a copyWith(...) function.
$StructuredFormatCopyWithExtension on StructuredFormat
This Extension on StructuredFormat is to generate the code for a copyWith(...) function.
$SubDestinationCopyWithExtension on SubDestination
This Extension on SubDestination is to generate the code for a copyWith(...) function.
$SuggestionCopyWithExtension on Suggestion
This Extension on Suggestion is to generate the code for a copyWith(...) function.
$TextSearchFilterCopyWithExtension on TextSearchFilter
This Extension on TextSearchFilter is to generate the code for a copyWith(...) function.
$ViewportCopyWithExtension on Viewport
This Extension on Viewport is to generate the code for a copyWith(...) function.
MapUtils on Map<K, V>

Typedefs

CancelTokenCallback = CancelToken Function()
TokenCallback = Future<String?> Function()
Callback for asynchronous token generation