AccessibilityOptions class

Information about the accessibility options a place offers.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#accessibilityoptions

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

AccessibilityOptions({bool? wheelchairAccessibleParking, bool? wheelchairAccessibleEntrance, bool? wheelchairAccessibleRestroom, bool? wheelchairAccessibleSeating})
AccessibilityOptions.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wheelchairAccessibleEntrance → bool?
Places has wheelchair accessible entrance.
final
wheelchairAccessibleParking → bool?
Place offers wheelchair accessible parking.
final
wheelchairAccessibleRestroom → bool?
Place has wheelchair accessible restroom.
final
wheelchairAccessibleSeating → bool?
Place has wheelchair accessible seating.
final

Methods

copyWith({bool? wheelchairAccessibleParking, bool? wheelchairAccessibleEntrance, bool? wheelchairAccessibleRestroom, bool? wheelchairAccessibleSeating}) → AccessibilityOptions

Available on AccessibilityOptions, provided by the $AccessibilityOptionsCopyWithExtension extension

fromJsonList(List? jsonList) → List<AccessibilityOptions>?
inherited
fromJsonMap(Map<String, dynamic>? json) → AccessibilityOptions?
override
fromJsonString(String? json) → AccessibilityOptions?
inherited
fromJsonStringList(String? jsonStringList) → List<AccessibilityOptions>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited