AddressComponent class

The structured components that form the formatted address, if this information is available.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#addresscomponent

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

AddressComponent({String? longText, String? shortText, List<PlaceType>? types, String? languageCode})
AddressComponent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode → String?
The language used to format this components, in CLDR notation.
final
longText → String?
The full text description or name of the address component. For example, an address component for the country Australia may have a long_name of "Australia".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortText → String?
An abbreviated textual name for the address component, if available. For example, an address component for the country of Australia may have a short_name of "AU".
final
types → List<PlaceType>?
An array indicating the type(s) of the address component.
final

Methods

copyWith({String? longText, String? shortText, List<PlaceType>? types, String? languageCode}) → AddressComponent

Available on AddressComponent, provided by the $AddressComponentCopyWithExtension extension

fromJsonList(List? jsonList) → List<AddressComponent>?
inherited
fromJsonMap(Map<String, dynamic>? json) → AddressComponent?
override
fromJsonString(String? json) → AddressComponent?
inherited
fromJsonStringList(String? jsonStringList) → List<AddressComponent>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited