Area class

Area information and the area's relationship with the target location.

Areas includes precise sublocality, neighborhoods, and large compounds that are useful for describing a location.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#area

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Area({String? name, String? placeId, LocalizedText? displayName, Containment? containment})
Area.fromJson(Map<String, dynamic> json)
factory

Properties

containment → Containment?
Defines the spatial relationship between the target location and the area.
final
displayName → LocalizedText?
The area's display name.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The area's resource name.
final
placeId → String?
The area's place id.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? placeId, LocalizedText? displayName, Containment? containment}) → Area

Available on Area, provided by the $AreaCopyWithExtension extension

fromJsonList(List? jsonList) → List<Area>?
inherited
fromJsonMap(Map<String, dynamic>? json) → Area?
override
fromJsonString(String? json) → Area?
inherited
fromJsonStringList(String? jsonStringList) → List<Area>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited