AreaSummary class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

AreaSummary({List<ContentBlock>? contentBlocks, String? flagContentUri})
AreaSummary.fromJson(Map<String, dynamic> json)
factory

Properties

contentBlocks → List<ContentBlock>?
Content blocks that compose the area summary. Each block has a separate topic about the area.
final
flagContentUri → String?
A link where users can flag a problem with the summary.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ContentBlock>? contentBlocks, String? flagContentUri}) → AreaSummary

Available on AreaSummary, provided by the $AreaSummaryCopyWithExtension extension

fromJsonList(List? jsonList) → List<AreaSummary>?
inherited
fromJsonMap(Map<String, dynamic>? json) → AreaSummary?
override
fromJsonString(String? json) → AreaSummary?
inherited
fromJsonStringList(String? jsonStringList) → List<AreaSummary>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited