AutocompleteSearchFilter class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

AutocompleteSearchFilter({String? sessionToken, String? languageCode, String? regionCode, String? input, LocationBias? locationBias, LocationRestriction? locationRestriction, List<PlaceType>? includedPrimaryTypes, List<String>? includedRegionCodes, LatLng? origin, int? inputOffset, bool? includeQueryPredictions, bool? includePureServiceAreaBusinesses})
AutocompleteSearchFilter.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → _$AutocompleteSearchFilterCWProxy

Available on AutocompleteSearchFilter, provided by the $AutocompleteSearchFilterCopyWith extension

Returns a callable class that can be used as follows: instanceOfAutocompleteSearchFilter.copyWith(...).
no setter
hashCode → int
The hash code for this object.
no setterinherited
includedPrimaryTypes → List<PlaceType>?
Optional. Included primary Place type (for example, "restaurant" or "gas_station") in Place Types (https://developers.google.com/maps/documentation/places/web-service/place-types), or only regions, or only cities. A Place is only returned if its primary type is included in this list. Up to 5 values can be specified. If no types are specified, all Place types are returned.
final
includedRegionCodes → List<String>?
Optional. Only include results in the specified regions, specified as up to 15 CLDR two-character region codes. An empty set will not restrict the results. If both locationRestriction and includedRegionCodes are set, the results will be located in the area of intersection.
final
includePureServiceAreaBusinesses → bool?
Optional. Include pure service area businesses if the field is set to true. Pure service area business is a business that visits or delivers to customers directly but does not serve customers at their business address. For example, businesses like cleaning services or plumbers. Those businesses do not have a physical address or location on Google Maps. Places will not return fields including location, plusCode, and other location related fields for these businesses.
final
includeQueryPredictions → bool?
Optional. If true, the response will include both Place and query predictions. Otherwise the response will only return Place predictions.
final
input → String?
Required. The text string on which to search.
final
inputOffset → int?
Optional. A zero-based Unicode character offset of input indicating the cursor position in input. The cursor position may influence what predictions are returned.
final
languageCode → String?
Place details will be displayed with the preferred language if available.
finalinherited
locationBias → LocationBias?
Optional. Bias results to a specified location.
final
locationRestriction → LocationRestriction?
Optional. Restrict results to a specified location.
final
origin → LatLng?
Optional. The origin point from which to calculate geodesic distance to the destination (returned as distanceMeters). If this value is omitted, geodesic distance will not be returned.
final
regionCode → String?
The Unicode country/region code (CLDR) of the location where the request is coming from. This parameter is used to display the place details, like region-specific place name, if available. The parameter can affect results based on applicable law. For more information, see https://www.unicode.org/cldr/charts/latest/supplemental/territory_language_information.html.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionToken → String?
A string which identifies an Autocomplete session for billing purposes. Must be a URL and filename safe base64 string with at most 36 ASCII characters in length. Otherwise an INVALID_ARGUMENT error is returned.
finalinherited

Methods

fromJsonList(List? jsonList) → List<AutocompleteSearchFilter>?
inherited
fromJsonMap(Map<String, dynamic>? json) → AutocompleteSearchFilter?
override
fromJsonString(String? json) → AutocompleteSearchFilter?
inherited
fromJsonStringList(String? jsonStringList) → List<AutocompleteSearchFilter>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited