BaseFilter<T extends Object> class abstract

Inheritance
Implementers

Constructors

BaseFilter({String? languageCode, String? regionCode})

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode → String?
Place details will be displayed with the preferred language if available.
final
regionCode → String?
The Unicode country/region code (CLDR) of the location where the request is coming from. This parameter is used to display the place details, like region-specific place name, if available. The parameter can affect results based on applicable law. For more information, see https://www.unicode.org/cldr/charts/latest/supplemental/territory_language_information.html.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJsonList(List? jsonList) → List<T>?
inherited
fromJsonMap(Map<String, dynamic>? json) → T?
override
fromJsonString(String? json) → T?
inherited
fromJsonStringList(String? jsonStringList) → List<T>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
inherited
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited