BusinessStatus enum

Inheritance
Available extensions

Values

businessStatusUnspecified → const BusinessStatus

Default value. This value is unused.

const BusinessStatus('BUSINESS_STATUS_UNSPECIFIED')
operational → const BusinessStatus

The establishment is operational, not necessarily open now.

const BusinessStatus('OPERATIONAL')
closedTemporarily → const BusinessStatus

The establishment is temporarily closed.

const BusinessStatus('CLOSED_TEMPORARILY')
closedPermanently → const BusinessStatus

The establishment is permanently closed.

const BusinessStatus('CLOSED_PERMANENTLY')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String name) → BusinessStatus?

Constants

values → const List<BusinessStatus>
A constant List of the values in this enum, in order of their declaration.