Circle class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Circle({required ReferencePoint center, double? radius})
Circle.fromJson(Map<String, dynamic> json)
factory

Properties

center → ReferencePoint
The center point of the Circle
final
hashCode → int
The hash code for this object.
no setterinherited
radius → double
The radius in meters must be between 1.0 and 50000.0, inclusive. The default radius is 500.0. You must set it in your request to a value greater than 0.0.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ReferencePoint? center, double? radius}) → Circle

Available on Circle, provided by the $CircleCopyWithExtension extension

fromJsonList(List? jsonList) → List<Circle>?
inherited
fromJsonMap(Map<String, dynamic>? json) → Circle?
override
fromJsonString(String? json) → Circle?
inherited
fromJsonStringList(String? jsonStringList) → List<Circle>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultRadius → const double