ConnectorAggregation class

EV charging information grouped by type, maxChargeRateKw. Shows EV charge aggregation of connectors that have the same type and max charge rate in kw.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#connectoraggregation

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

ConnectorAggregation({EvConnectorType? type, double? maxChargeRateKw, int? count, DateTime? availabilityLastUpdateTime, int? availableCount, int? outOfServiceCount})
ConnectorAggregation.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityLastUpdateTime → DateTime?
The timestamp when the connector availability information in this aggregation was last updated.
final
availableCount → int?
Number of connectors in this aggregation that are currently available.
final
count → int?
Number of connectors in this aggregation.
final
hashCode → int
The hash code for this object.
no setterinherited
maxChargeRateKw → double?
The static max charging rate in kw of each connector in the aggregation.
final
outOfServiceCount → int?
Number of connectors in this aggregation that are currently out of service.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → EvConnectorType?
The connector type of this aggregation.
final

Methods

copyWith({EvConnectorType? type, double? maxChargeRateKw, int? count, DateTime? availabilityLastUpdateTime, int? availableCount, int? outOfServiceCount}) → ConnectorAggregation

Available on ConnectorAggregation, provided by the $ConnectorAggregationCopyWithExtension extension

fromJsonList(List? jsonList) → List<ConnectorAggregation>?
inherited
fromJsonMap(Map<String, dynamic>? json) → ConnectorAggregation?
override
fromJsonString(String? json) → ConnectorAggregation?
inherited
fromJsonStringList(String? jsonStringList) → List<ConnectorAggregation>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited