Containment enum

Defines the spatial relationship between the target location and the area. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#containment

Inheritance
Available extensions

Values

containmentUnspecified → const Containment

The containment is unspecified.

const Containment('CONTAINMENT_UNSPECIFIED')
within → const Containment

The target location is within the area region, close to the center.

const Containment('WITHIN')
outskirts → const Containment

The target location is within the area region, close to the edge.

const Containment('OUTSKIRTS')
near → const Containment

The target location is outside the area region, but close by.

const Containment('NEAR')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String name) → Containment?

Constants

values → const List<Containment>
A constant List of the values in this enum, in order of their declaration.