ContentBlock class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

ContentBlock({String? topic, LocalizedText? content, References? references})
ContentBlock.fromJson(Map<String, dynamic> json)
factory

Properties

content → LocalizedText?
Content related to the topic.
final
hashCode → int
The hash code for this object.
no setterinherited
references → References?
Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String?
The topic of the content, for example "overview" or "restaurant".
final

Methods

copyWith({String? topic, LocalizedText? content, References? references}) → ContentBlock

Available on ContentBlock, provided by the $ContentBlockCopyWithExtension extension

fromJsonList(List? jsonList) → List<ContentBlock>?
inherited
fromJsonMap(Map<String, dynamic>? json) → ContentBlock?
override
fromJsonString(String? json) → ContentBlock?
inherited
fromJsonStringList(String? jsonStringList) → List<ContentBlock>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited