EVChargeOptions class

Information about the EV Charge Station hosted in Place. Terminology follows https://afdc.energy.gov/fuels/electricity_infrastructure.html One port could charge one car at a time. One port has one or more connectors. One station has one or more ports.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#evchargeoptions

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

EVChargeOptions({int? connectorCount, List<ConnectorAggregation>? connectorAggregation})
EVChargeOptions.fromJson(Map<String, dynamic> json)
factory

Properties

connectorAggregation → List<ConnectorAggregation>?
A list of EV charging connector aggregations that contain connectors of the same type and same charge rate.
final
connectorCount → int?
Number of connectors at this station. However, because some ports can have multiple connectors but only be able to charge one car at a time (e.g.) the number of connectors may be greater than the total number of cars which can charge simultaneously.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? connectorCount, List<ConnectorAggregation>? connectorAggregation}) → EVChargeOptions

Available on EVChargeOptions, provided by the $EVChargeOptionsCopyWithExtension extension

fromJsonList(List? jsonList) → List<EVChargeOptions>?
inherited
fromJsonMap(Map<String, dynamic>? json) → EVChargeOptions?
override
fromJsonString(String? json) → EVChargeOptions?
inherited
fromJsonStringList(String? jsonStringList) → List<EVChargeOptions>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited