ErrorInfo class

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ErrorInfo({int? code, String? message, String? status, dynamic details})
ErrorInfo.fromJson(Map<String, dynamic> json)
factory

Properties

code → int?
final
details → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final

Methods

fromJsonList(List? jsonList) → List<ErrorInfo>?
inherited
fromJsonMap(Map<String, dynamic>? json) → ErrorInfo?
override
fromJsonString(String? json) → ErrorInfo?
inherited
fromJsonStringList(String? jsonStringList) → List<ErrorInfo>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited