FuelOptions class

The most recent information about fuel options in a gas station. This information is updated regularly.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#fueloptions

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

FuelOptions({List<FuelPrice>? fuelPrices})
FuelOptions.fromJson(Map<String, dynamic> json)
factory

Properties

fuelPrices → List<FuelPrice>?
The last known fuel price for each type of fuel this station has. There is one entry per fuel type this station has. Order is not important.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<FuelPrice>? fuelPrices}) → FuelOptions

Available on FuelOptions, provided by the $FuelOptionsCopyWithExtension extension

fromJsonList(List? jsonList) → List<FuelOptions>?
inherited
fromJsonMap(Map<String, dynamic>? json) → FuelOptions?
override
fromJsonString(String? json) → FuelOptions?
inherited
fromJsonStringList(String? jsonStringList) → List<FuelOptions>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited