FuelPrice class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

FuelPrice({FuelType? type, Money? price, DateTime? updateTime})
FuelPrice.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
price → Money?
The price of the fuel.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FuelType?
The type of fuel.
final
updateTime → DateTime?
The time the fuel price was last updated.
final

Methods

copyWith({FuelType? type, Money? price, DateTime? updateTime}) → FuelPrice

Available on FuelPrice, provided by the $FuelPriceCopyWithExtension extension

fromJsonList(List? jsonList) → List<FuelPrice>?
inherited
fromJsonMap(Map<String, dynamic>? json) → FuelPrice?
override
fromJsonString(String? json) → FuelPrice?
inherited
fromJsonStringList(String? jsonStringList) → List<FuelPrice>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited