FuelType enum

Inheritance
Available extensions

Values

fuelTypeUnspecified → const FuelType

Unspecified fuel type.

const FuelType('FUEL_TYPE_UNSPECIFIED')
diesel → const FuelType

Diesel fuel.

const FuelType('DIESEL')
regularUnleaded → const FuelType

Regular unleaded.

const FuelType('REGULAR_UNLEADED')
midgrade → const FuelType

Midgrade.

const FuelType('MIDGRADE')
premium → const FuelType

Premium.

const FuelType('PREMIUM')
sp91 → const FuelType

SP 91.

const FuelType('SP91')
sp91E10 → const FuelType

SP 91 E10.

const FuelType('SP91_E10')
sp92 → const FuelType

SP 92.

const FuelType('SP92')
sp95 → const FuelType

SP 95.

const FuelType('SP95')
sp95E10 → const FuelType

SP95 E10.

const FuelType('SP95_E10')
sp98 → const FuelType

SP 98.

const FuelType('SP98')
sp99 → const FuelType

SP 99.

const FuelType('SP99')
sp100 → const FuelType

SP 100.

const FuelType('SP100')
lpg → const FuelType

LPG.

const FuelType('LPG')
e80 → const FuelType

E 80.

const FuelType('E80')
e85 → const FuelType

E 85.

const FuelType('E85')
methane → const FuelType

Methane.

const FuelType('METHANE')
bioDiesel → const FuelType

Bio-diesel.

const FuelType('BIO_DIESEL')
truckDiesel → const FuelType

Truck diesel.

const FuelType('TRUCK_DIESEL')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String name) → FuelType?

Constants

values → const List<FuelType>
A constant List of the values in this enum, in order of their declaration.