GenerativeSummary class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

GenerativeSummary({LocalizedText? overview, String? overviewFlagContentUri, LocalizedText? description, String? descriptionFlagContentUri, References? references})
GenerativeSummary.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → _$GenerativeSummaryCWProxy

Available on GenerativeSummary, provided by the $GenerativeSummaryCopyWith extension

Returns a callable class that can be used as follows: instanceOfGenerativeSummary.copyWith(...).
no setter
description → LocalizedText?
The detailed description of the place.
final
descriptionFlagContentUri → String?
A link where users can flag a problem with the description summary.
final
hashCode → int
The hash code for this object.
no setterinherited
overview → LocalizedText?
The overview of the place.
final
overviewFlagContentUri → String?
A link where users can flag a problem with the overview summary.
final
references → References?
References that are used to generate the summary description.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJsonList(List? jsonList) → List<GenerativeSummary>?
inherited
fromJsonMap(Map<String, dynamic>? json) → GenerativeSummary?
override
fromJsonString(String? json) → GenerativeSummary?
inherited
fromJsonStringList(String? jsonStringList) → List<GenerativeSummary>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited