GoogleMapsLinks class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

GoogleMapsLinks({String? directionsUri, String? placeUri, String? writeAReviewUri, String? reviewsUri, String? photosUri})
GoogleMapsLinks.fromJson(Map<String, dynamic> json)
factory

Properties

directionsUri → String?
A link to show the directions to the place. The link only populates the destination location and uses the default travel mode DRIVE.
final
hashCode → int
The hash code for this object.
no setterinherited
photosUri → String?
A link to show photos of this place. This link is currently not supported on Google Maps Mobile and only works on the web version of Google Maps.
final
placeUri → String?
A link to show this place.
final
reviewsUri → String?
A link to show reviews of this place. This link is currently not supported on Google Maps Mobile and only works on the web version of Google Maps.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeAReviewUri → String?
A link to write a review for this place. This link is currently not supported on Google Maps Mobile and only works on the web version of Google Maps.
final

Methods

copyWith({String? directionsUri, String? placeUri, String? writeAReviewUri, String? reviewsUri, String? photosUri}) → GoogleMapsLinks

Available on GoogleMapsLinks, provided by the $GoogleMapsLinksCopyWithExtension extension

fromJsonList(List? jsonList) → List<GoogleMapsLinks>?
inherited
fromJsonMap(Map<String, dynamic>? json) → GoogleMapsLinks?
override
fromJsonString(String? json) → GoogleMapsLinks?
inherited
fromJsonStringList(String? jsonStringList) → List<GoogleMapsLinks>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited