Leg class

A leg is a single portion of a journey from one location to another.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/RoutingSummary#leg

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Leg({String? duration, int? distanceMeters})
Leg.fromJson(Map<String, dynamic> json)
factory

Properties

distanceMeters → int?
final
duration → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? duration, int? distanceMeters}) → Leg

Available on Leg, provided by the $LegCopyWithExtension extension

fromJsonList(List? jsonList) → List<Leg>?
inherited
fromJsonMap(Map<String, dynamic>? json) → Leg?
override
fromJsonString(String? json) → Leg?
inherited
fromJsonStringList(String? jsonStringList) → List<Leg>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited