LocalizedText class

Localized variant of a text in a particular language. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#localizedtext

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

LocalizedText({String? text, String? languageCode})
LocalizedText.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode → String?
The text's BCP-47 language code, such as "en-US" or "sr-Latn". For more information, see http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
Localized string in the language corresponding to languageCode below.
final

Methods

copyWith({String? text, String? languageCode}) → LocalizedText

Available on LocalizedText, provided by the $LocalizedTextCopyWithExtension extension

fromJsonList(List? jsonList) → List<LocalizedText>?
inherited
fromJsonMap(Map<String, dynamic>? json) → LocalizedText?
override
fromJsonString(String? json) → LocalizedText?
inherited
fromJsonStringList(String? jsonStringList) → List<LocalizedText>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited