LocationMultiArea class

Inheritance
Implementers
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

LocationMultiArea({Circle? circle, Rectangle? rectangle})
LocationMultiArea.fromJson(Map<String, dynamic> json)
factory

Properties

circle → Circle?
final
hashCode → int
The hash code for this object.
no setterinherited
rectangle → Rectangle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Circle? circle, Rectangle? rectangle}) → LocationMultiArea

Available on LocationMultiArea, provided by the $LocationMultiAreaCopyWithExtension extension

fromJsonList(List? jsonList) → List<LocationMultiArea>?
inherited
fromJsonMap(Map<String, dynamic>? json) → LocationMultiArea?
override
fromJsonString(String? json) → LocationMultiArea?
inherited
fromJsonStringList(String? jsonStringList) → List<LocationMultiArea>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited