ParkingOptions class

Information about parking options for the place. A parking lot could support more than one option at the same time.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#parkingoptions

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

ParkingOptions({bool? freeParkingLot, bool? paidParkingLot, bool? freeStreetParking, bool? paidStreetParking, bool? valetParking, bool? freeGarageParking, bool? paidGarageParking})
ParkingOptions.fromJson(Map<String, dynamic> json)
factory

Properties

freeGarageParking → bool?
Place offers free garage parking.
final
freeParkingLot → bool?
Place offers free parking lots.
final
freeStreetParking → bool?
Place offers free street parking.
final
hashCode → int
The hash code for this object.
no setterinherited
paidGarageParking → bool?
Place offers paid garage parking.
final
paidParkingLot → bool?
Place offers paid parking lots.
final
paidStreetParking → bool?
Place offers paid street parking.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valetParking → bool?
Place offers valet parking.
final

Methods

copyWith({bool? freeParkingLot, bool? paidParkingLot, bool? freeStreetParking, bool? paidStreetParking, bool? valetParking, bool? freeGarageParking, bool? paidGarageParking}) → ParkingOptions

Available on ParkingOptions, provided by the $ParkingOptionsCopyWithExtension extension

fromJsonList(List? jsonList) → List<ParkingOptions>?
inherited
fromJsonMap(Map<String, dynamic>? json) → ParkingOptions?
override
fromJsonString(String? json) → ParkingOptions?
inherited
fromJsonStringList(String? jsonStringList) → List<ParkingOptions>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited