PaymentOptions class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

PaymentOptions({bool? acceptsCreditCards, bool? acceptsDebitCards, bool? acceptsCashOnly, bool? acceptsNfc})
PaymentOptions.fromJson(Map<String, dynamic> json)
factory

Properties

acceptsCashOnly → bool?
Place accepts cash only as payment. Places with this attribute may still accept other payment methods.
final
acceptsCreditCards → bool?
Place accepts credit cards as payment.
final
acceptsDebitCards → bool?
Place accepts debit cards as payment.
final
acceptsNfc → bool?
Place accepts NFC payments.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? acceptsCreditCards, bool? acceptsDebitCards, bool? acceptsCashOnly, bool? acceptsNfc}) → PaymentOptions

Available on PaymentOptions, provided by the $PaymentOptionsCopyWithExtension extension

fromJsonList(List? jsonList) → List<PaymentOptions>?
inherited
fromJsonMap(Map<String, dynamic>? json) → PaymentOptions?
override
fromJsonString(String? json) → PaymentOptions?
inherited
fromJsonStringList(String? jsonStringList) → List<PaymentOptions>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited