Period class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Period({Point? open, Point? close})
Period.fromJson(Map<String, dynamic> json)
factory

Properties

close → Point?
The time that the place starts to be closed.
final
hashCode → int
The hash code for this object.
no setterinherited
open → Point?
The time that the place starts to be open.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Point? open, Point? close}) → Period

Available on Period, provided by the $PeriodCopyWithExtension extension

fromJsonList(List? jsonList) → List<Period>?
inherited
fromJsonMap(Map<String, dynamic>? json) → Period?
override
fromJsonString(String? json) → Period?
inherited
fromJsonStringList(String? jsonStringList) → List<Period>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited