Photo class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Photo({String? name, int? widthPx, int? heightPx, List<AuthorAttribution>? authorAttributions, String? flagContentUri, String? googleMapsUri, String? photoUri})
Photo.fromJson(Map<String, dynamic> json)
factory

Properties

authorAttributions → List<AuthorAttribution>?
This photo's authors.
final
flagContentUri → String?
A link where users can flag a problem with the photo.
final
googleMapsUri → String?
A link to show the photo on Google Maps.
final
hashCode → int
The hash code for this object.
no setterinherited
heightPx → int?
The maximum available height, in pixels.
final
name → String?
Identifier. A reference representing this place photo which may be used to look up this place photo again (also called the API "resource" name: places/{placeId}/photos/{photo}).
final
photoUri → String?
A link to the photo's URL.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widthPx → int?
The maximum available width, in pixels.
final

Methods

copyWith({String? name, int? widthPx, int? heightPx, List<AuthorAttribution>? authorAttributions, String? flagContentUri, String? googleMapsUri, String? photoUri}) → Photo

Available on Photo, provided by the $PhotoCopyWithExtension extension

fromJsonList(List? jsonList) → List<Photo>?
inherited
fromJsonMap(Map<String, dynamic>? json) → Photo?
override
fromJsonString(String? json) → Photo?
inherited
fromJsonStringList(String? jsonStringList) → List<Photo>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited