Place class

All the information representing a Place.

Documentation:https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#Place

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Place({String? name, String? id, LocalizedText? displayName, List<PlaceType>? types, PlaceType? primaryType, LocalizedText? primaryTypeDisplayName, String? nationalPhoneNumber, String? internationalPhoneNumber, String? formattedAddress, String? shortFormattedAddress, List<AddressComponent>? addressComponents, PlusCode? plusCode, LatLng? location, Viewport? viewport, double? rating, String? googleMapsUri, String? websiteUri, List<Review>? reviews, OpeningHours? regularOpeningHours, List<Photo>? photos, String? adrFormatAddress, BusinessStatus? businessStatus, PriceLevel? priceLevel, List<Attribution>? attributions, String? iconMaskBaseUri, String? iconBackgroundColor, OpeningHours? currentOpeningHours, List<OpeningHours>? currentSecondaryOpeningHours, List<OpeningHours>? regularSecondaryOpeningHours, LocalizedText? editorialSummary, PaymentOptions? paymentOptions, ParkingOptions? parkingOptions, List<SubDestination>? subDestinations, FuelOptions? fuelOptions, EVChargeOptions? evChargeOptions, GenerativeSummary? generativeSummary, AreaSummary? areaSummary, List<ContainingPlace>? containingPlaces, AddressDescriptor? addressDescriptor, GoogleMapsLinks? googleMapsLinks, PriceRange? priceRange, int? utcOffsetMinutes, int? userRatingCount, bool? takeout, bool? delivery, bool? dineIn, bool? curbsidePickup, bool? reservable, bool? servesBreakfast, bool? servesLunch, bool? servesDinner, bool? servesBeer, bool? servesWine, bool? servesBrunch, bool? servesVegetarianFood, bool? outdoorSeating, bool? liveMusic, bool? menuForChildren, bool? servesCocktails, bool? servesDessert, bool? servesCoffee, bool? goodForChildren, bool? allowsDogs, bool? restroom, bool? goodForGroups, bool? goodForWatchingSports, AccessibilityOptions? accessibilityOptions, bool? pureServiceAreaBusiness})
Place.fromJson(Map<String, dynamic> json)
factory

Properties

accessibilityOptions → AccessibilityOptions?
Information about the accessibility options a place offers.
final
addressComponents → List<AddressComponent>?
Repeated components for each locality level. Note the following facts about the addressComponents[] array: - The array of address components may contain more components than the formattedAddress. - The array does not necessarily include all the political entities that contain an address, apart from those included in the formattedAddress. To retrieve all the political entities that contain a specific address, you should use reverse geocoding, passing the latitude/longitude of the address as a parameter to the request.
final
addressDescriptor → AddressDescriptor?
The address descriptor of the place. Address descriptors include additional information that help describe a location using landmarks and areas. See address descriptor regional coverage in https://developers.google.com/maps/documentation/geocoding/address-descriptors/coverage.
final
adrFormatAddress → String?
The place's address in adr microformat: http://microformats.org/wiki/adr.
final
allowsDogs → bool?
Place allows dogs.
final
areaSummary → AreaSummary?
Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details.
final
attributions → List<Attribution>?
A set of data provider that must be shown with this result.
final
businessStatus → BusinessStatus?
The business status for the place.
final
containingPlaces → List<ContainingPlace>?
List of places in which the current place is located.
final
curbsidePickup → bool?
Specifies if the business supports curbside pickup.
final
currentOpeningHours → OpeningHours?
The hours of operation for the next seven days (including today). The time period starts at midnight on the date of the request and ends at 11:59 pm six days later. This field includes the specialDays subfield of all hours, set for dates that have exceptional hours.
final
currentSecondaryOpeningHours → List<OpeningHours>?
Contains an array of entries for the next seven days including information about secondary hours of a business. Secondary hours are different from a business's main hours. For example, a restaurant can specify drive through hours or delivery hours as its secondary hours. This field populates the type subfield, which draws from a predefined list of opening hours types (such as DRIVE_THROUGH, PICKUP, or TAKEOUT) based on the types of the place. This field includes the specialDays subfield of all hours, set for dates that have exceptional hours.
final
delivery → bool?
Specifies if the business supports delivery.
final
dineIn → bool?
Specifies if the business supports indoor or outdoor seating options.
final
displayName → LocalizedText?
The localized name of the place, suitable as a short human-readable description. For example, "Google Sydney", "Starbucks", "Pyrmont", etc.
final
editorialSummary → LocalizedText?
Contains a summary of the place. A summary is comprised of a textual overview, and also includes the language code for these if applicable. Summary text must be presented as-is and can not be modified or altered.
final
evChargeOptions → EVChargeOptions?
Information of ev charging options.
final
formattedAddress → String?
A full, human-readable address for this place.
final
fuelOptions → FuelOptions?
The most recent information about fuel options in a gas station. This information is updated regularly.
final
generativeSummary → GenerativeSummary?
Experimental: See https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative for more details.
final
goodForChildren → bool?
Place is good for children.
final
goodForGroups → bool?
Place accommodates groups.
final
goodForWatchingSports → bool?
Place is suitable for watching sports.
final
Links to trigger different Google Maps actions.
final
googleMapsUri → String?
A URL providing more information about this place.
final
hashCode → int
The hash code for this object.
no setterinherited
iconBackgroundColor → String?
Background color for icon_mask in hex format, e.g. #909CE1.
final
iconMaskBaseUri → String?
A truncated URL to an icon mask. User can access different icon type by appending type suffix to the end (eg, ".svg" or ".png").
final
id → String?
The unique identifier of a place.
final
internationalPhoneNumber → String?
A human-readable phone number for the place, in international format.
final
liveMusic → bool?
Place provides live music.
final
location → LatLng?
The position of this place.
final
Place has a children's menu.
final
name → String?
This Place's resource name, in places/{placeId} format. Can be used to look up the Place.
final
nationalPhoneNumber → String?
A human-readable phone number for the place, in national format.
final
outdoorSeating → bool?
Place provides outdoor seating.
final
parkingOptions → ParkingOptions?
Options of parking provided by the place.
final
paymentOptions → PaymentOptions?
Payment options the place accepts. If a payment option data is not available, the payment option field will be unset.
final
photos → List<Photo>?
Information (including references) about photos of this place. A maximum of 10 photos can be returned.
final
plusCode → PlusCode?
Plus code of the place location lat/long.
final
priceLevel → PriceLevel?
Price level of the place.
final
priceRange → PriceRange?
The price range associated with a Place.
final
primaryType → PlaceType?
The primary type of the given result. This type must one of the Places API supported types. For example, "restaurant", "cafe", "airport", etc. A place can only have a single primary type. For the complete list of possible values, see Table A and Table B at https://developers.google.com/maps/documentation/places/web-service/place-types
final
primaryTypeDisplayName → LocalizedText?
The display name of the primary type, localized to the request language if applicable. For the complete list of possible values, see Table A and Table B at https://developers.google.com/maps/documentation/places/web-service/place-types
final
pureServiceAreaBusiness → bool?
Indicates whether the place is a pure service area business. Pure service area business is a business that visits or delivers to customers directly but does not serve customers at their business address. For example, businesses like cleaning services or plumbers. Those businesses may not have a physical address or location on Google Maps.
final
rating → double?
A rating between 1.0 and 5.0, based on user reviews of this place.
final
regularOpeningHours → OpeningHours?
The regular hours of operation. Note that if a place is always open (24 hours), the close field will not be set. Clients can rely on always open (24 hours) being represented as an OpeningHours.Period.open period containing Point.day with value 0, Point.hour with value 0, and Point.minute with value 0.
final
regularSecondaryOpeningHours → List<OpeningHours>?
Contains an array of entries for information about regular secondary hours of a business. Secondary hours are different from a business's main hours. For example, a restaurant can specify drive through hours or delivery hours as its secondary hours. This field populates the type subfield, which draws from a predefined list of opening hours types (such as DRIVE_THROUGH, PICKUP, or TAKEOUT) based on the types of the place.
final
reservable → bool?
Specifies if the place supports reservations.
final
restroom → bool?
Place has restroom.
final
reviews → List<Review>?
List of reviews about this place, sorted by relevance. A maximum of 5 reviews can be returned.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servesBeer → bool?
Specifies if the place serves beer.
final
servesBreakfast → bool?
Specifies if the place serves breakfast.
final
servesBrunch → bool?
Specifies if the place serves brunch.
final
servesCocktails → bool?
Place serves cocktails.
final
servesCoffee → bool?
Place serves coffee.
final
servesDessert → bool?
Place serves dessert.
final
servesDinner → bool?
Specifies if the place serves dinner.
final
servesLunch → bool?
Specifies if the place serves lunch.
final
servesVegetarianFood → bool?
Specifies if the place serves vegetarian food.
final
servesWine → bool?
Specifies if the place serves wine.
final
shortFormattedAddress → String?
A short, human-readable address for this place.
final
subDestinations → List<SubDestination>?
A list of sub destinations related to the place.
final
takeout → bool?
Specifies if the business supports takeout.
final
types → List<PlaceType>?
A set of type tags for this result. For example, "political" and "locality". For the complete list of possible values, see Table A and Table B at https://developers.google.com/maps/documentation/places/web-service/place-types
final
userRatingCount → int?
The total number of reviews (with or without text) for this place.
final
utcOffsetMinutes → int?
Number of minutes this place's timezone is currently offset from UTC. This is expressed in minutes to support timezones that are offset by fractions of an hour, e.g. X hours and 15 minutes.
final
viewport → Viewport?
A viewport suitable for displaying the place on an average-sized map. This viewport should not be used as the physical boundary or the service area of the business.
final
websiteUri → String?
The authoritative website for this place, e.g. a business' homepage. Note that for places that are part of a chain (e.g. an IKEA store), this will usually be the website for the individual store, not the overall chain.
final

Methods

copyWith({String? name, String? id, LocalizedText? displayName, List<PlaceType>? types, PlaceType? primaryType, LocalizedText? primaryTypeDisplayName, String? nationalPhoneNumber, String? internationalPhoneNumber, String? formattedAddress, String? shortFormattedAddress, List<AddressComponent>? addressComponents, PlusCode? plusCode, LatLng? location, Viewport? viewport, double? rating, String? googleMapsUri, String? websiteUri, List<Review>? reviews, OpeningHours? regularOpeningHours, List<Photo>? photos, String? adrFormatAddress, BusinessStatus? businessStatus, PriceLevel? priceLevel, List<Attribution>? attributions, String? iconMaskBaseUri, String? iconBackgroundColor, OpeningHours? currentOpeningHours, List<OpeningHours>? currentSecondaryOpeningHours, List<OpeningHours>? regularSecondaryOpeningHours, LocalizedText? editorialSummary, PaymentOptions? paymentOptions, ParkingOptions? parkingOptions, List<SubDestination>? subDestinations, FuelOptions? fuelOptions, EVChargeOptions? evChargeOptions, GenerativeSummary? generativeSummary, AreaSummary? areaSummary, List<ContainingPlace>? containingPlaces, AddressDescriptor? addressDescriptor, GoogleMapsLinks? googleMapsLinks, PriceRange? priceRange, int? utcOffsetMinutes, int? userRatingCount, bool? takeout, bool? delivery, bool? dineIn, bool? curbsidePickup, bool? reservable, bool? servesBreakfast, bool? servesLunch, bool? servesDinner, bool? servesBeer, bool? servesWine, bool? servesBrunch, bool? servesVegetarianFood, bool? outdoorSeating, bool? liveMusic, bool? menuForChildren, bool? servesCocktails, bool? servesDessert, bool? servesCoffee, bool? goodForChildren, bool? allowsDogs, bool? restroom, bool? goodForGroups, bool? goodForWatchingSports, AccessibilityOptions? accessibilityOptions, bool? pureServiceAreaBusiness}) → Place

Available on Place, provided by the $PlaceCopyWithExtension extension

fromJsonList(List? jsonList) → List<Place>?
inherited
fromJsonMap(Map<String, dynamic>? json) → Place?
override
fromJsonString(String? json) → Place?
inherited
fromJsonStringList(String? jsonStringList) → List<Place>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited