PlacePrediction class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

PlacePrediction({String? place, String? placeId, FormattableText? text, StructuredFormat? structuredFormat, List<PlaceType>? types, int? distanceMeters})
PlacePrediction.fromJson(Map<String, dynamic> json)
factory

Properties

distanceMeters → int?
The length of the geodesic in meters from origin if origin is specified. Certain predictions such as routes may not populate this field.
final
hashCode → int
The hash code for this object.
no setterinherited
place → String?
The resource name of the suggested Place. This name can be used in other APIs that accept Place names.
final
placeId → String?
The unique identifier of the suggested Place. This identifier can be used in other APIs that accept Place IDs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredFormat → StructuredFormat?
A breakdown of the Place prediction into main text containing the name of the Place and secondary text containing additional disambiguating features (such as a city or region).
final
text → FormattableText?
Contains the human-readable name for the returned result. For establishment results, this is usually the business name and address.
final
types → List<PlaceType>?
List of types that apply to this Place from Table A or Table B in https://developers.google.com/maps/documentation/places/web-service/place-types.
final

Methods

copyWith({String? place, String? placeId, FormattableText? text, StructuredFormat? structuredFormat, List<PlaceType>? types, int? distanceMeters}) → PlacePrediction

Available on PlacePrediction, provided by the $PlacePredictionCopyWithExtension extension

fromJsonList(List? jsonList) → List<PlacePrediction>?
inherited
fromJsonMap(Map<String, dynamic>? json) → PlacePrediction?
override
fromJsonString(String? json) → PlacePrediction?
inherited
fromJsonStringList(String? jsonStringList) → List<PlacePrediction>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited