PriceLevel enum

Inheritance
Available extensions

Values

unspecified → const PriceLevel

Place price level is unspecified or unknown.

const PriceLevel('PRICE_LEVEL_UNSPECIFIED', -1)
free → const PriceLevel

Place provides free services.

const PriceLevel('PRICE_LEVEL_FREE', 0)
inexpensive → const PriceLevel

Place provides inexpensive services.

const PriceLevel('PRICE_LEVEL_INEXPENSIVE', 1)
moderate → const PriceLevel

Place provides moderately priced services.

const PriceLevel('PRICE_LEVEL_MODERATE', 2)
expensive → const PriceLevel

Place provides expensive services.

const PriceLevel('PRICE_LEVEL_EXPENSIVE', 3)
veryExpensive → const PriceLevel

Place provides very expensive services.

const PriceLevel('PRICE_LEVEL_VERY_EXPENSIVE', 4)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
levelIndex → int
The index of the price level from -1 to 4. This value can be used as a reference of the legacy Place PriceLevel from old apis.
final
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String name) → PriceLevel?

Constants

values → const List<PriceLevel>
A constant List of the values in this enum, in order of their declaration.