PriceRange class

The price range associated with a Place. endPrice could be unset, which indicates a range without upper bound (e.g. "More than $100").

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#pricerange

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

PriceRange({Money? startPrice, Money? endPrice})
PriceRange.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → _$PriceRangeCWProxy

Available on PriceRange, provided by the $PriceRangeCopyWith extension

Returns a callable class that can be used as follows: instanceOfPriceRange.copyWith(...).
no setter
endPrice → Money?
The high end of the price range (exclusive). Price should be lower than this amount.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startPrice → Money?
The low end of the price range (inclusive). Price should be at or above this amount.
final

Methods

fromJsonList(List? jsonList) → List<PriceRange>?
inherited
fromJsonMap(Map<String, dynamic>? json) → PriceRange?
override
fromJsonString(String? json) → PriceRange?
inherited
fromJsonStringList(String? jsonStringList) → List<PriceRange>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited