QueryPrediction class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

QueryPrediction({FormattableText? text, StructuredFormat? structuredFormat})
QueryPrediction.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredFormat → StructuredFormat?
A breakdown of the query prediction into main text containing the query and secondary text containing additional disambiguating features (such as a city or region).
final
text → FormattableText?
The predicted text. This text does not represent a Place, but rather a text query that could be used in a search endpoint (for example, Text Search).
final

Methods

copyWith({FormattableText? text, StructuredFormat? structuredFormat}) → QueryPrediction

Available on QueryPrediction, provided by the $QueryPredictionCopyWithExtension extension

fromJsonList(List? jsonList) → List<QueryPrediction>?
inherited
fromJsonMap(Map<String, dynamic>? json) → QueryPrediction?
override
fromJsonString(String? json) → QueryPrediction?
inherited
fromJsonStringList(String? jsonStringList) → List<QueryPrediction>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited