RankPreferenceType enum

The type of ranking to use in a search like nearby search. Documentation: https://developers.google.com/maps/documentation/places/web-service/nearby-search#rankpreference

Inheritance
Available extensions

Values

popularity → const RankPreferenceType

Sorts results based on their popularity.

const RankPreferenceType('POPULARITY')
relevance → const RankPreferenceType

Sorts results based on search relevance.

const RankPreferenceType('RELEVANCE')
distance → const RankPreferenceType

Sorts results in ascending order by their distance from the specified location.

const RankPreferenceType('DISTANCE')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

nearbySearchRankPreferences → const List<RankPreferenceType>
textSearchRankPreferences → const List<RankPreferenceType>
values → const List<RankPreferenceType>
A constant List of the values in this enum, in order of their declaration.