ReferencePoint class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

ReferencePoint({required double latitude, required double longitude})
ReferencePoint.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
latitude → double
final
longitude → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? latitude, double? longitude}) → ReferencePoint

Available on ReferencePoint, provided by the $ReferencePointCopyWithExtension extension

fromJsonList(List? jsonList) → List<ReferencePoint>?
inherited
fromJsonMap(Map<String, dynamic>? json) → ReferencePoint?
override
fromJsonString(String? json) → ReferencePoint?
inherited
fromJsonStringList(String? jsonStringList) → List<ReferencePoint>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited