References class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

References({List<Review>? reviews, List<String>? places})
References.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
places → List<String>?
The list of resource names of the referenced places. This name can be used in other APIs that accept Place resource names.
final
reviews → List<Review>?
Reviews that serve as references.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<Review>? reviews, List<String>? places}) → References

Available on References, provided by the $ReferencesCopyWithExtension extension

fromJsonList(List? jsonList) → List<References>?
inherited
fromJsonMap(Map<String, dynamic>? json) → References?
override
fromJsonString(String? json) → References?
inherited
fromJsonStringList(String? jsonStringList) → List<References>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited