Review class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Review({String? name, String? relativePublishTimeDescription, LocalizedText? text, LocalizedText? originalText, int? rating, AuthorAttribution? authorAttribution, DateTime? publishTime, String? flagContentUri, String? googleMapsUri})
Review.fromJson(Map<String, dynamic> json)
factory

Properties

authorAttribution → AuthorAttribution?
This review's author.
final
flagContentUri → String?
A link where users can flag a problem with the review.
final
googleMapsUri → String?
A link to show the review on Google Maps.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
A reference representing this place review which may be used to look up this place review again (also called the API "resource" name: places/{placeId}/reviews/{review}).
final
originalText → LocalizedText?
The review text in its original language.
final
publishTime → DateTime?
Timestamp for the review. A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits. Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
final
rating → int?
A number between 1.0 and 5.0, also called the number of stars.
final
relativePublishTimeDescription → String?
A string of formatted recent time, expressing the review time relative to the current time in a form appropriate for the language and country.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → LocalizedText?
The localized text of the review.
final

Methods

copyWith({String? name, String? relativePublishTimeDescription, LocalizedText? text, LocalizedText? originalText, int? rating, AuthorAttribution? authorAttribution, DateTime? publishTime, String? flagContentUri, String? googleMapsUri}) → Review

Available on Review, provided by the $ReviewCopyWithExtension extension

fromJsonList(List? jsonList) → List<Review>?
inherited
fromJsonMap(Map<String, dynamic>? json) → Review?
override
fromJsonString(String? json) → Review?
inherited
fromJsonStringList(String? jsonStringList) → List<Review>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited