RouteModifiers class

Encapsulates a set of optional conditions to satisfy when calculating the routes.

Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/RoutingParameters#routemodifiers

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

RouteModifiers({bool? avoidTolls, bool? avoidHighways, bool? avoidFerries, bool? avoidIndoor})
RouteModifiers.fromJson(Map<String, dynamic> json)
factory

Properties

avoidFerries → bool?
Optional. When set to true, avoids ferries where reasonable, giving preference to routes not containing ferries. Applies only to the DRIVE and TWO_WHEELER TravelMode.
final
avoidHighways → bool?
Optional. When set to true, avoids highways where reasonable, giving preference to routes not containing highways. Applies only to the DRIVE and TWO_WHEELER TravelMode.
final
avoidIndoor → bool?
Optional. When set to true, avoids navigating indoors where reasonable, giving preference to routes not containing indoor navigation. Applies only to the WALK TravelMode.
final
avoidTolls → bool?
Optional. When set to true, avoids toll roads where reasonable, giving preference to routes not containing toll roads. Applies only to the DRIVE and TWO_WHEELER TravelMode.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? avoidTolls, bool? avoidHighways, bool? avoidFerries, bool? avoidIndoor}) → RouteModifiers

Available on RouteModifiers, provided by the $RouteModifiersCopyWithExtension extension

fromJsonList(List? jsonList) → List<RouteModifiers>?
inherited
fromJsonMap(Map<String, dynamic>? json) → RouteModifiers?
override
fromJsonString(String? json) → RouteModifiers?
inherited
fromJsonStringList(String? jsonStringList) → List<RouteModifiers>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited