RoutingParameters class
Information about the accessibility options a place offers.
Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#RoutingParameters
- Inheritance
-
- Object
- Jsonable<
RoutingParameters> - RoutingParameters
- Available extensions
- Annotations
-
- @JsonSerializable.new()
- @CopyWith.new()
Constructors
- RoutingParameters({LatLng? origin, TravelMode? travelMode, RouteModifiers? routeModifiers, RoutingPreference? routingPreference})
-
RoutingParameters.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- origin → LatLng?
-
Optional. An explicit routing origin that overrides the origin defined in
the polyline. By default, the polyline origin is used.
final
- routeModifiers → RouteModifiers?
-
Optional. The route modifiers.
final
- routingPreference → RoutingPreference?
-
Optional. Specifies how to compute the routing summaries. The server
attempts to use the selected routing preference to compute the route. The
traffic aware routing preference is only available for the DRIVE or
TWO_WHEELER travelMode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- travelMode → TravelMode?
-
Optional. The travel mode.
final
Methods
-
copyWith(
{LatLng? origin, TravelMode? travelMode, RouteModifiers? routeModifiers, RoutingPreference? routingPreference}) → RoutingParameters -
Available on RoutingParameters, provided by the $RoutingParametersCopyWithExtension extension
-
fromJsonList(
List? jsonList) → List< RoutingParameters> ? -
inherited
-
fromJsonMap(
Map< String, dynamic> ? json) → RoutingParameters? -
override
-
fromJsonString(
String? json) → RoutingParameters? -
inherited
-
fromJsonStringList(
String? jsonStringList) → List< RoutingParameters> ? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFieldsMask(
{String? parentKey}) → List< String> -
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toJsonMap(
) → Map< String, dynamic> -
inherited
-
toJsonString(
) → String -
inherited
-
toString(
) → String -
This is just to suggest children to implement a named constructor to
support creating objects fromJson(...) and fromJsonString(...) as easy as
T.build().fromJson(...) or T.build().fromJsonString(...)
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited