RoutingPreference enum

A set of values that specify factors to take into consideration when calculating the route. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/RoutingParameters#routingpreference

Inheritance
Available extensions

Values

routingPreferenceUnspecified → const RoutingPreference

No routing preference specified. Default to TRAFFIC_UNAWARE.

const RoutingPreference('ROUTING_PREFERENCE_UNSPECIFIED')
trafficUnaware → const RoutingPreference

Computes routes without taking live traffic conditions into consideration. Suitable when traffic conditions don't matter or are not applicable. Using this value produces the lowest latency. Note: For TravelMode DRIVE and TWO_WHEELER, the route and duration chosen are based on road network and average time-independent traffic conditions, not current road conditions. Consequently, routes may include roads that are temporarily closed. Results for a given request may vary over time due to changes in the road network, updated average traffic conditions, and the distributed nature of the service. Results may also vary between nearly-equivalent routes at any time or frequency.

const RoutingPreference('TRAFFIC_UNAWARE')
trafficAware → const RoutingPreference

Calculates routes taking live traffic conditions into consideration. In contrast to TRAFFIC_AWARE_OPTIMAL, some optimizations are applied to significantly reduce latency.

const RoutingPreference('TRAFFIC_AWARE')
trafficAwareOptimal → const RoutingPreference

Calculates the routes taking live traffic conditions into consideration, without applying most performance optimizations. Using this value produces the highest latency.

const RoutingPreference('TRAFFIC_AWARE_OPTIMAL')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String name) → RoutingPreference?

Constants

values → const List<RoutingPreference>
A constant List of the values in this enum, in order of their declaration.