SecondaryHoursType enum

Inheritance
Available extensions

Values

secondaryHoursTypeUnspecified → const SecondaryHoursType

Default value when secondary hour type is not specified.

const SecondaryHoursType('SECONDARY_HOURS_TYPE_UNSPECIFIED')
driveThrough → const SecondaryHoursType

The drive-through hour for banks, restaurants, or pharmacies.

const SecondaryHoursType('DRIVE_THROUGH')
happyHour → const SecondaryHoursType

The happy hour.

const SecondaryHoursType('HAPPY_HOUR')
delivery → const SecondaryHoursType

The delivery hour.

const SecondaryHoursType('DELIVERY')
takeout → const SecondaryHoursType

The takeout hour.

const SecondaryHoursType('TAKEOUT')
kitchen → const SecondaryHoursType

The kitchen hour.

const SecondaryHoursType('KITCHEN')
breakfast → const SecondaryHoursType

The breakfast hour.

const SecondaryHoursType('BREAKFAST')
lunch → const SecondaryHoursType

The lunch hour.

const SecondaryHoursType('LUNCH')
dinner → const SecondaryHoursType

The dinner hour.

const SecondaryHoursType('DINNER')
brunch → const SecondaryHoursType

The brunch hour.

const SecondaryHoursType('BRUNCH')
pickup → const SecondaryHoursType

The pickup hour.

const SecondaryHoursType('PICKUP')
access → const SecondaryHoursType

The access hours for storage places.

const SecondaryHoursType('ACCESS')
seniorHours → const SecondaryHoursType

The special hours for seniors.

const SecondaryHoursType('SENIOR_HOURS')
onlineServiceHours → const SecondaryHoursType

The online service hours.

const SecondaryHoursType('ONLINE_SERVICE_HOURS')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String name) → SecondaryHoursType?

Constants

values → const List<SecondaryHoursType>
A constant List of the values in this enum, in order of their declaration.