SpatialRelationship enum

Defines the spatial relationship between the target location and the landmark. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#spatialrelationship

Inheritance
Available extensions

Values

near → const SpatialRelationship

This is the default relationship when nothing more specific below applies.

const SpatialRelationship('NEAR')
within → const SpatialRelationship

The landmark has a spatial geometry and the target is within its bounds.

const SpatialRelationship('WITHIN')
beside → const SpatialRelationship

The target is directly adjacent to the landmark.

const SpatialRelationship('BESIDE')
acrossTheRoad → const SpatialRelationship

The target is directly opposite the landmark on the other side of the road.

const SpatialRelationship('ACROSS_THE_ROAD')
downTheRoad → const SpatialRelationship

On the same route as the landmark but not besides or across.

const SpatialRelationship('DOWN_THE_ROAD')
aroundTheCorner → const SpatialRelationship

Not on the same route as the landmark but a single turn away.

const SpatialRelationship('AROUND_THE_CORNER')
behind → const SpatialRelationship

Close to the landmark's structure but further away from its street entrances.

const SpatialRelationship('BEHIND')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String name) → SpatialRelationship?

Constants

values → const List<SpatialRelationship>
A constant List of the values in this enum, in order of their declaration.