StringRange class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

StringRange({int? startOffset, int? endOffset})
StringRange.fromJson(Map<String, dynamic> json)
factory

Properties

endOffset → int?
Zero-based offset of the last Unicode character (exclusive).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startOffset → int?
Zero-based offset of the first Unicode character of the string (inclusive).
final

Methods

copyWith({int? startOffset, int? endOffset}) → StringRange

Available on StringRange, provided by the $StringRangeCopyWithExtension extension

fromJsonList(List? jsonList) → List<StringRange>?
inherited
fromJsonMap(Map<String, dynamic>? json) → StringRange?
override
fromJsonString(String? json) → StringRange?
inherited
fromJsonStringList(String? jsonStringList) → List<StringRange>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited