Suggestion class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Suggestion({PlacePrediction? placePrediction, QueryPrediction? queryPrediction})
Suggestion.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
placePrediction → PlacePrediction?
A prediction for a Place.
final
queryPrediction → QueryPrediction?
A prediction for a query.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({PlacePrediction? placePrediction, QueryPrediction? queryPrediction}) → Suggestion

Available on Suggestion, provided by the $SuggestionCopyWithExtension extension

fromJsonList(List? jsonList) → List<Suggestion>?
inherited
fromJsonMap(Map<String, dynamic>? json) → Suggestion?
override
fromJsonString(String? json) → Suggestion?
inherited
fromJsonStringList(String? jsonStringList) → List<Suggestion>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) → List<String>
inherited
toJson() → Map<String, dynamic>
override
toJsonMap() → Map<String, dynamic>
inherited
toJsonString() → String
inherited
toString() → String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited