TravelMode enum

Travel mode options. These options map to what Routes API offers. Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/RoutingParameters#travelmode

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(fieldRename: FieldRename.screamingSnake)

Values

travelModeUnspecified → const TravelMode

No travel mode specified. Defaults to DRIVE.

const TravelMode('TRAVEL_MODE_UNSPECIFIED')
drive → const TravelMode

Travel by passenger car.

const TravelMode('DRIVE')
bicycle → const TravelMode

Travel by bicycle. Not supported with searchAlongRouteParameters.

const TravelMode('BICYCLE')
walk → const TravelMode

Travel by walking. Not supported with searchAlongRouteParameters.

const TravelMode('WALK')
twoWheeler → const TravelMode

Motorized two wheeled vehicles of all kinds such as scooters and motorcycles. Note that this is distinct from the BICYCLE travel mode which covers human-powered transport. Not supported with searchAlongRouteParameters. Only supported in those countries listed at Countries and regions supported for two-wheeled vehicles.

const TravelMode('TWO_WHEELER')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String name) → TravelMode?

Constants

values → const List<TravelMode>
A constant List of the values in this enum, in order of their declaration.