Attribution class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()
  • @CopyWith.new()

Constructors

Attribution({String? provider, String? providerUri})
Attribution.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
provider String?
Name of the Place's data provider.
final
providerUri String?
URI to the Place's data provider.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? provider, String? providerUri}) Attribution

Available on Attribution, provided by the $AttributionCopyWithExtension extension

fromJsonList(List? jsonList) List<Attribution>?
inherited
fromJsonMap(Map<String, dynamic>? json) Attribution?
override
fromJsonString(String? json) Attribution?
inherited
fromJsonStringList(String? jsonStringList) List<Attribution>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFieldsMask({String? parentKey}) List<String>
inherited
toJson() Map<String, dynamic>
override
toJsonMap() Map<String, dynamic>
inherited
toJsonString() String
inherited
toString() String
This is just to suggest children to implement a named constructor to support creating objects fromJson(...) and fromJsonString(...) as easy as T.build().fromJson(...) or T.build().fromJsonString(...)
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited