SubDestination class
Place resource name and id of sub destinations that relate to the place. For example, different terminals are different destinations of an airport.
Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#subdestination
- Inheritance
-
- Object
- Jsonable<
SubDestination> - SubDestination
- Available extensions
- Annotations
-
- @JsonSerializable.new()
- @CopyWith.new()
Constructors
- SubDestination({String? name, String? id})
-
SubDestination.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
copyWith(
{String? name, String? id}) → SubDestination -
Available on SubDestination, provided by the $SubDestinationCopyWithExtension extension
-
fromJsonList(
List? jsonList) → List< SubDestination> ? -
inherited
-
fromJsonMap(
Map< String, dynamic> ? json) → SubDestination? -
override
-
fromJsonString(
String? json) → SubDestination? -
inherited
-
fromJsonStringList(
String? jsonStringList) → List< SubDestination> ? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFieldsMask(
{String? parentKey}) → List< String> -
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toJsonMap(
) → Map< String, dynamic> -
inherited
-
toJsonString(
) → String -
inherited
-
toString(
) → String -
This is just to suggest children to implement a named constructor to
support creating objects fromJson(...) and fromJsonString(...) as easy as
T.build().fromJson(...) or T.build().fromJsonString(...)
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited