Viewport class
A latitude-longitude viewport, represented as two diagonally opposite low and high points. A viewport is considered a closed region, i.e. it includes its boundary. The latitude bounds must range between -90 to 90 degrees inclusive, and the longitude bounds must range between -180 to 180 degrees inclusive.
Documentation: https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#viewport
- Inheritance
- Available extensions
- Annotations
-
- @JsonSerializable.new()
- @CopyWith.new()
Constructors
Properties
Methods
-
copyWith(
{LatLng? low, LatLng? high}) → Viewport -
Available on Viewport, provided by the $ViewportCopyWithExtension extension
-
fromJsonList(
List? jsonList) → List< Viewport> ? -
inherited
-
fromJsonMap(
Map< String, dynamic> ? json) → Viewport? -
override
-
fromJsonString(
String? json) → Viewport? -
inherited
-
fromJsonStringList(
String? jsonStringList) → List< Viewport> ? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFieldsMask(
{String? parentKey}) → List< String> -
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toJsonMap(
) → Map< String, dynamic> -
inherited
-
toJsonString(
) → String -
inherited
-
toString(
) → String -
This is just to suggest children to implement a named constructor to
support creating objects fromJson(...) and fromJsonString(...) as easy as
T.build().fromJson(...) or T.build().fromJsonString(...)
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited